<?php

/**
 * @package ecommerce
 */
 
/**
 * Sub-class of Payment that supports the Paymex Start-Up account as its payment processor
 * The Start-Up account allows us to redirect the customer to a secure payment page, and be returned back to Paymex
 * upon success.
 *
 * Original version written by Paymex Limited with support from Jack Pivac (Delphinus)
 * July 2008
*/
 
/** 
 *  Configuration
 *  =============
 *  You will firstly need to enable the payment module with something like:
 *  Payment::set_supported_methods(array(
 *    'PaymexPayment' => 'Credit Card (Paymex)'));
 *
 *  You then need to define the business id and test mode in _config.php of your project:
 *  PaymexPayment::SetBusinessId("de0adb6e-17ff-4d72-996e-6fb2ec8b7080");
 *  PaymexPayment::SetTestMode(true);
 */
class PaymexPayment extends Payment {
    
    /* Properties */
    
    protected static $business_id;
    static function SetBusinessId($id) {
        self::$business_id = $id;
    }
    static function GetBusinessId() {
        return self::$business_id;
    }
    protected static $px_testmode;
    static function SetTestMode($testmode) {
        self::$px_testmode = $testmode;
    }
    static function GetTestMode() {
        return self::$px_testmode;
    }

    /* Methods */
    
    function getPaymentFormFields() {
        return new FieldSet(
            new LiteralField(
                "CCblurb", 
                "<div id=\"Payment\">".
                    "<a href=\"http://www.paymex.co.nz/\" target=\"_blank\" title=\"Click here to visit Paymex\">".
                        "<img src=\"https://secure.paymex.co.nz/images/payment_methods2.png\" alt=\"Credit card payments powered by Paymex\" />".
                    "</a>".
                "</div>")
        );	
    }
    function getPaymentFormRequirements() {
        return null;
    }
    
    /*
     * Returns the Cheque content from the CheckoutPage
     */
    function ChequeContent() {
        return DataObject::get_one('CheckoutPage')->ChequeMessage;
    }
    
    function processPayment($data, $form) {
        $tmpPage = new Page();
        $tmpPage->Title = "Make payment";
        $tmpPage->Content = $this->StartPaymexForm();
        $tmpPage->URLSegment = "payment";

        $controller = new Page_Controller($tmpPage);
        //Controller::pushCurrent();
        
        $form = $controller->renderWith("Page");
        
        return array('Success' => false, 'Processing' => true, 'ReturnValue' => $form);
    }
    
    function StartPaymexForm() {
        $m = $this->Member();
        $o = DataObject::get_by_id("Order", $this->OrderID);

        //Get the call back URL
        $callbackURL = Director::absoluteBaseURL(). 'PaymexPayment_Handler/paid/' . $this->ID;
        
        // Build up some item statement information
        $item_number = '';
        $item_name = '';
        $item_qty = '';
        $item_amt = '';
        
        $items = $o->Items();
        if($items) {
            $pipe_required = false;
            
            //Go through each item
            foreach($items as $item) {
                
                //Add a pipe if it is required
                if ($pipe_required) {
                    $item_number .= '|';
                    $item_name .= '|';
                    $item_qty .= '|';
                    $item_amt .= '|';                
                }
                else
                    $pipe_required = true;

                //Append the real details
                $item_number .= $item->ProductID;
                $item_name .= $item->Title;
                $item_qty .= $item->Quantity;
                $item_amt .= $item->UnitPrice;                
            }
        }
        
        $info = array(
            "business" => self::$business_id, //The business id
            "test_mode" => self::$px_testmode, //Indicating whether we are testing the module
            "client_ref" => "Order #$this->OrderID", //The reference to be applied to the client statement
            "retail_ref" => "Order #$this->OrderID", //The reference to be applied to the retailer statement
            "ex_orderid" => $this->OrderID, //This is an extension field used for IPN checking
            "currency_code" => Order::site_currency(), //The currency of the transaction
            //"amount" => $this->Amount,
            "item_number" => $item_number,
            "item_name" => $item_name,
            "item_qty" => $item_qty,
            "amount" => $item_amt,
            "shipping" => $o->Shipping(),
            
            "cc_only" => "1", //Indicate that we are only accepting credit card
            "hide_extra" => "1", //If we can, we'll hide the billing/shipping details
            
            "return" => $callbackURL, // Send them back to the IPN handler
            "return_cancel" => Director::absoluteBaseURL().'checkout', //Make the cancel page comes back here
            "notify_type" => "return", //We'll make the return page the IPN handler so ensure the variables are sent to this page
            
            //Default some billing details
            "first_name" => $m->FirstName, //Default the first name
            "last_name" => $m->Surname, //Default the last name
            "address1" => $m->Address,
            "address2" => "", //I would suggest having an address2 AND a suburb - but since this doesn't accept it yet leave this blank and fill in suburb
            "suburb" => $m->AddressLine2,
            "city" => $m->City,
            "country" => $m->Country,
            "email" => $m->Email,
            "postcode" => $m->Postcode,
            "phone" => $m->HomePhone
        );
        
        //Should we supply shipping details?
        if ($o->UseShippingAddress) {
            $info['shipping_address'] = '1';
            $info['specify_shipping_address'] = '1';
            $info['ship_address1'] = $o->ShippingAddress;
            $info['ship_address2'] = ""; //I would suggest having an address2 AND a suburb - but since this doesn't accept it yet leave this blank and fill in suburb
            $info['ship_suburb'] = $o->ShippingAddress2;
            $info['ship_city'] = $o->ShippingCity;
            $info['ship_postcode'] = '';
            $info['ship_country'] = $o->ShippingCountry;
        }
        $fields = '';
        foreach($info as $k => $v) {
            $fields .= "<input type=\"hidden\" name=\"" . Convert::raw2att($k) . "\" value=\"" . Convert::raw2att($v) . "\" />\n";
        }
        $business_id = self::$business_id;
        return <<<HTML
            <form id="PaymentForm" method="post" action="https://secure.paymex.co.nz/Process.aspx">
                <h2>Now forwarding you to Paymex...</h2>
                $fields
                <p class="Actions" id="Submit">
                   <input type="submit" value="Make Payment" />
                </p>
                <p id="Submitting" style="display: none">We are now redirecting you to Paymex...</p>
            </form>
            
            <script>
                $('Submit').style.display = 'none';
                $('Submitting').style.display = '';
                $('PaymentForm').submit();
            </script>

HTML;
    }
    
    function getPaymentFormRequiredFields() {
        return array();
    }
}

/**
 * Handler for IPN responses from the Paymex site
 */
class PaymexPayment_Handler extends Controller {

    /*
    * This function accepts various arguments and returns a boolean indicating whether the transaction is valid or not.
    */
    function verify_ipn($business, $amount, $txnId, &$message) {
        $pxNotificationServer = "secure.paymex.co.nz";
        $pxNotificationPath = "/ipn.ashx";
    	
    	//Build the data
    	$data = 'business='.rawurlencode($business);
    	$data .= '&txnid='.rawurlencode($txnId);
    	$data .= '&amount='.rawurlencode($amount);
    	
        $context_options = array(
        'http'=>array(
        'method'=>"POST",
        'header'=>"Accept-language: en\r\n" .
        "Content-length: " . strlen ($data) . "\r\n" .
        "Content-type:application/x-www-form-urlencoded\r\n",
        'content'=> $data)
        );
        // Make sure the HTTPS options are the same as HTTP
        $context_options['https'] = $context_options['http'];
        $context = stream_context_create($context_options);
        $fp = fopen('https://'.$pxNotificationServer.$pxNotificationPath, 'r', false, $context);
        $header = '';
        
    	// Check HTTP connection made ok
    	if (!$fp) 
    		return -1;

    	fputs($fp, $header . $data);
    	
    	//Read the results
    	$results = '';
    	while (!feof($fp)) 
    	{
    		$results .= fgets ($fp, 1024);
    	}
    	preg_match_all( "/\<success\>(.*?)\<\/success\>/", $results, $success);
    	$success = $success[1][0];
    	preg_match_all( "/\<message\>(.*?)\<\/message\>/", $results, $message);
    	$message = $message[1][0];
    	if ($success == 'True')
    		return 1;

    	return 0;
    }
    
    function generateError($error_msg, $error_type) {
        if (PaymexPayment::GetTestMode())
            echo 'An error was encountered during verification: '.$error_msg;
        trigger_error($error_msg, $error_type);
    }
    /**
     * Get the Order object to modify, ensure that it has been paid based upon Paymex IPN 
     * and update the Order object to show complete and Payment object to show
     * that it was received. Finally, send a receipt to the buyer to show these details.
     */		
    function paid() {
        global $project;
    
        // Check if callback password is the same, otherwise fail
        if(!array_key_exists('Error', $_REQUEST)) {
            if(array_key_exists('txnid', $_REQUEST) && array_key_exists('ex_orderid', $_REQUEST)) {

                // The transaction id and order id was specified so check it out!
                // Check if the order ID is numeric, otherwise fail
                $orderID = $_REQUEST['ex_orderid'];
                if(is_numeric($orderID)) {
                    $order = DataObject::get_one("Order", "`Order`.ID = $orderID");
                    if($order) {
                        
                        //If this has already been paid then just make it a success
                        if ($order->Status == 'Paid') {
                            $url = Director::absoluteBaseURL() . CheckoutPage::find_link(true) . "/OrderSuccessful/".$orderID;
                        }
                        else {
                            //Ok, so we found the order id - now check that it can verify
                            $verificationMessage = '';
                            if ($this->verify_ipn(PaymexPayment::GetBusinessId(), $order->_Total(), $_REQUEST['txnid'], $verificationMessage)) {
                                $order->Status = 'Paid';
                                $order->write();
                            
                                $payment = DataObject::get_one("Payment", "`Payment`.`OrderID` = '$orderID'");
                                if($payment) {
                                    $payment->Status = "Success";
                                    $payment->write();
                                
                                    // create a log-entry for it
                                    $logEntry = new OrderStatusLog();
                                    $logEntry->OrderID = $orderID;
                                    $logEntry->Status = 'Paid';
                                    $logEntry->write();
                                } else {
                                    $this->generateError("CheckoutPage::OrderConfirmed - There is no Payment object for this order object (Order ID ".$orderID.")", E_USER_WARNING);
                                }
                                // @todo Work out a good way to store Paymex's transactional information
                                // send request
                                //
                            
                                $order->Member();
                                // TODO - FIX THIS, emails at the moment are inaccurate because GeoIP fails to find
                                // for example, it finds the shipping country as the UK (and thus breaks shipping / tax logic in email)
                                //$order->sendReceipt();

                                $url = Director::absoluteBaseURL() . CheckoutPage::find_link(true) . "/OrderSuccessful/".$orderID;
                            } else {
                                $this->generateError("CheckoutPage::OrderConfirmed - Order cannot be verified: ".$verificationMessage,E_USER_WARNING);
                                return;
                            }    
                        }
                    } else {
                        $this->generateError("CheckoutPage::OrderConfirmed - Order cannot be found",E_USER_WARNING);
                        return;
                    }
                } else {
                    $orderID = $_REQUEST['ex_orderid'];
                    $url = Director::absoluteBaseURL() . CheckoutPage::find_link(true) . "/OrderIncomplete/".$orderID;
                }
            } else {
                $this->generateError("CheckoutPage::OrderConfirmed - Order error - Payment transaction id or invoice id not specified",E_USER_WARNING);
                return;
            }
        
        } else {
            $this->generateError("CheckoutPage::OrderConfirmed - Order error - Payment transaction id not specified: ".$_REQUEST['Error'] ,E_USER_WARNING);
            return;
        }
    
        // In the absence of an error, go to the Order complete/incomplete page.
        echo "<html><head><meta http-equiv=\"Refresh\" content=\"0;url=$url\"></head><body>Redirecting to <a href=\"$url\">$url</a></body></html>";
    }
}

?>